@@ -30,7 +30,7 @@ type FieldsList = Punctuated<Field, Comma>;
 fn encode_single_field(
 	field: &Field,
 	field_name: TokenStream,
-	crate_ident: &TokenStream,
+	crate_path: &syn::Path,
 ) -> TokenStream {
 	let encoded_as = utils::get_encoded_as_type(field);
 	let compact = utils::is_compact(field);
@@ -53,8 +53,8 @@ fn encode_single_field(
 		let field_type = &field.ty;
 		quote_spanned! {
 			field.span() => {
-				<<#field_type as #crate_ident::HasCompact>::Type as
-				#crate_ident::EncodeAsRef<'_, #field_type>>::RefType::from(#field_name)
+				<<#field_type as #crate_path::HasCompact>::Type as
+				#crate_path::EncodeAsRef<'_, #field_type>>::RefType::from(#field_name)
 			}
 		}
 	} else if let Some(encoded_as) = encoded_as {
@@ -62,7 +62,7 @@ fn encode_single_field(
 		quote_spanned! {
 			field.span() => {
 				<#encoded_as as
-				#crate_ident::EncodeAsRef<'_, #field_type>>::RefType::from(#field_name)
+				#crate_path::EncodeAsRef<'_, #field_type>>::RefType::from(#field_name)
 			}
 		}
 	} else {
@@ -75,19 +75,19 @@ fn encode_single_field(
 	let i_self = quote! { self };
 
 	quote_spanned! { field.span() =>
-			fn encode_to<__CodecOutputEdqy: #crate_ident::Output + ?::core::marker::Sized>(
+			fn encode_to<__CodecOutputEdqy: #crate_path::Output + ?::core::marker::Sized>(
 				&#i_self,
 				__codec_dest_edqy: &mut __CodecOutputEdqy
 			) {
-				#crate_ident::Encode::encode_to(&#final_field_variable, __codec_dest_edqy)
+				#crate_path::Encode::encode_to(&#final_field_variable, __codec_dest_edqy)
 			}
 
-			fn encode(&#i_self) -> #crate_ident::alloc::vec::Vec<::core::primitive::u8> {
-				#crate_ident::Encode::encode(&#final_field_variable)
+			fn encode(&#i_self) -> #crate_path::alloc::vec::Vec<::core::primitive::u8> {
+				#crate_path::Encode::encode(&#final_field_variable)
 			}
 
 			fn using_encoded<R, F: ::core::ops::FnOnce(&[::core::primitive::u8]) -> R>(&#i_self, f: F) -> R {
-				#crate_ident::Encode::using_encoded(&#final_field_variable, f)
+				#crate_path::Encode::using_encoded(&#final_field_variable, f)
 			}
 	}
 }
@@ -96,7 +96,7 @@ fn encode_fields<F>(
 	dest: &TokenStream,
 	fields: &FieldsList,
 	field_name: F,
-	crate_ident: &TokenStream,
+	crate_path: &syn::Path,
 ) -> TokenStream where
 	F: Fn(usize, &Option<Ident>) -> TokenStream,
 {
@@ -119,10 +119,10 @@ fn encode_fields<F>(
 			let field_type = &f.ty;
 			quote_spanned! {
 				f.span() => {
-					#crate_ident::Encode::encode_to(
+					#crate_path::Encode::encode_to(
 						&<
-							<#field_type as #crate_ident::HasCompact>::Type as
-							#crate_ident::EncodeAsRef<'_, #field_type>
+							<#field_type as #crate_path::HasCompact>::Type as
+							#crate_path::EncodeAsRef<'_, #field_type>
 						>::RefType::from(#field),
 						#dest,
 					);
@@ -132,10 +132,10 @@ fn encode_fields<F>(
 			let field_type = &f.ty;
 			quote_spanned! {
 				f.span() => {
-					#crate_ident::Encode::encode_to(
+					#crate_path::Encode::encode_to(
 						&<
 							#encoded_as as
-							#crate_ident::EncodeAsRef<'_, #field_type>
+							#crate_path::EncodeAsRef<'_, #field_type>
 						>::RefType::from(#field),
 						#dest,
 					);
@@ -147,7 +147,7 @@ fn encode_fields<F>(
 			}
 		} else {
 			quote_spanned! { f.span() =>
-				#crate_ident::Encode::encode_to(#field, #dest);
+				#crate_path::Encode::encode_to(#field, #dest);
 			}
 		}
 	});
@@ -157,7 +157,7 @@ fn encode_fields<F>(
 	}
 }
 
-fn try_impl_encode_single_field_optimisation(data: &Data, crate_ident: &TokenStream) -> Option<TokenStream> {
+fn try_impl_encode_single_field_optimisation(data: &Data, crate_path: &syn::Path) -> Option<TokenStream> {
 	match *data {
 		Data::Struct(ref data) => {
 			match data.fields {
@@ -167,7 +167,7 @@ fn try_impl_encode_single_field_optimisation(data: &Data, crate_ident: &TokenStr
 					Some(encode_single_field(
 						field,
 						quote!(&self.#name),
-						crate_ident,
+						crate_path,
 					))
 				},
 				Fields::Unnamed(ref fields) if utils::filter_skip_unnamed(fields).count() == 1 => {
@@ -177,7 +177,7 @@ fn try_impl_encode_single_field_optimisation(data: &Data, crate_ident: &TokenStr
 					Some(encode_single_field(
 						field,
 						quote!(&self.#id),
-						crate_ident,
+						crate_path,
 					))
 				},
 				_ => None,
@@ -187,7 +187,7 @@ fn try_impl_encode_single_field_optimisation(data: &Data, crate_ident: &TokenStr
 	}
 }
 
-fn impl_encode(data: &Data, type_name: &Ident, crate_ident: &TokenStream) -> TokenStream {
+fn impl_encode(data: &Data, type_name: &Ident, crate_path: &syn::Path) -> TokenStream {
 	let self_ = quote!(self);
 	let dest = &quote!(__codec_dest_edqy);
 	let encoding = match *data {
@@ -197,7 +197,7 @@ fn impl_encode(data: &Data, type_name: &Ident, crate_ident: &TokenStream) -> Tok
 					dest,
 					&fields.named,
 					|_, name| quote!(&#self_.#name),
-					crate_ident,
+					crate_path,
 				),
 				Fields::Unnamed(ref fields) => encode_fields(
 					dest,
@@ -206,7 +206,7 @@ fn impl_encode(data: &Data, type_name: &Ident, crate_ident: &TokenStream) -> Tok
 						let i = syn::Index::from(i);
 						quote!(&#self_.#i)
 					},
-					crate_ident,
+					crate_path,
 				),
 				Fields::Unit => quote!(),
 			}
@@ -242,7 +242,7 @@ fn impl_encode(data: &Data, type_name: &Ident, crate_ident: &TokenStream) -> Tok
 							dest,
 							&fields.named,
 							|a, b| field_name(a, b),
-							crate_ident,
+							crate_path,
 						);
 
 						quote_spanned! { f.span() =>
@@ -268,7 +268,7 @@ fn impl_encode(data: &Data, type_name: &Ident, crate_ident: &TokenStream) -> Tok
 							dest,
 							&fields.unnamed,
 							|a, b| field_name(a, b),
-							crate_ident,
+							crate_path,
 						);
 
 						quote_spanned! { f.span() =>
@@ -301,7 +301,7 @@ fn impl_encode(data: &Data, type_name: &Ident, crate_ident: &TokenStream) -> Tok
 		).to_compile_error(),
 	};
 	quote! {
-		fn encode_to<__CodecOutputEdqy: #crate_ident::Output + ?::core::marker::Sized>(
+		fn encode_to<__CodecOutputEdqy: #crate_path::Output + ?::core::marker::Sized>(
 			&#self_,
 			#dest: &mut __CodecOutputEdqy
 		) {
@@ -310,11 +310,11 @@ fn impl_encode(data: &Data, type_name: &Ident, crate_ident: &TokenStream) -> Tok
 	}
 }
 
-pub fn quote(data: &Data, type_name: &Ident, crate_ident: &TokenStream) -> TokenStream {
-	if let Some(implementation) = try_impl_encode_single_field_optimisation(data, crate_ident) {
+pub fn quote(data: &Data, type_name: &Ident, crate_path: &syn::Path) -> TokenStream {
+	if let Some(implementation) = try_impl_encode_single_field_optimisation(data, crate_path) {
 		implementation
 	} else {
-		impl_encode(data, type_name, crate_ident)
+		impl_encode(data, type_name, crate_path)
 	}
 }
 
